add missing comment to wfstack.c
[urcu.git] / urcu.h
diff --git a/urcu.h b/urcu.h
index da0b295ba9d72ec21c4ea1f3291f22ad669665b2..c6c54e7c7c3bcbc83d88b279e20ab35f64a0806f 100644 (file)
--- a/urcu.h
+++ b/urcu.h
@@ -6,7 +6,7 @@
  *
  * Userspace RCU header
  *
- * Copyright (c) 2009 Mathieu Desnoyers <mathieu.desnoyers@polymtl.ca>
+ * Copyright (c) 2009 Mathieu Desnoyers <mathieu.desnoyers@efficios.com>
  * Copyright (c) 2009 Paul E. McKenney, IBM Corporation.
  *
  * LGPL-compatible code should include this header with :
@@ -92,9 +92,9 @@ extern void rcu_register_thread(void);
 extern void rcu_unregister_thread(void);
 
 /*
* Explicit urcu initialization, for "early" use within library constructors.
  */
-extern void urcu_init(void);
+extern void rcu_init(void);
 
 #ifdef __cplusplus 
 }
@@ -92,9 +92,9 @@ extern void rcu_register_thread(void);
 
 /*
- * Explicit urcu initialization, for "early" use within library constructors.
+ * Explicit rcu initialization, for "early" use within library constructors.
  */
This page took 0.022514 seconds and 4 git commands to generate.